import {async, ComponentFixture, TestBed} from '@angular/core/testing';

import {CalibratorsComponent} from './calibrators.component';
import {Calibrator} from "../model/calibrator";
import {Flux} from "../model/flux";
import {Component, Input} from "@angular/core";
import {CalibratorsService} from "../services/calibrators.service";
import {of} from "rxjs";

// mock the child component
@Component({
  selector: 'app-calibrator',
  template: '<p>Mock App-calibrator component</p>'
})
class MockChildComponent {
  @Input() calibrator: Calibrator;
  @Input() flux: Flux;
}


describe('CalibratorsComponent', () => {
  let component: CalibratorsComponent;
  let fixture: ComponentFixture<CalibratorsComponent>;
  let calibratorServiceSpy: { getCalibrators: jasmine.Spy }; // we'll use a spy in place of the real service

  beforeEach(async(() => {
    calibratorServiceSpy = jasmine.createSpyObj('CalibratorsService', ['getCalibrators']);
    TestBed.configureTestingModule({
      declarations: [CalibratorsComponent, MockChildComponent],
      providers: [{provide: CalibratorsService, useValue: calibratorServiceSpy}]
    })
      .compileComponents();
  }));

  beforeEach(() => {
    fixture = TestBed.createComponent(CalibratorsComponent);
    component = fixture.componentInstance;
    calibratorServiceSpy = TestBed.get(CalibratorsService);
  });

  it('should create', () => {
    let expectedReturn = of([new Calibrator()]);
    calibratorServiceSpy.getCalibrators.and.returnValue(expectedReturn);
    fixture.detectChanges(); //ngOnInit
    expect(component).toBeTruthy();
  });

  it('should get calibrations on init', () => {
    let expectedReturn = of([]);
    calibratorServiceSpy.getCalibrators.and.returnValue(expectedReturn);

    fixture.detectChanges(); // ngOnInit

    expect(calibratorServiceSpy.getCalibrators.calls.any()).toBeTruthy('calibrator service called');
    expect(component.calibrators).toEqual(expectedReturn, 'calibrators set');
  });
});
