import {Component, Input, OnDestroy, OnInit} from '@angular/core';
import {ProductVersion} from "../../../../model/product";
import {JobSpec} from "../../../../model/job";
import {Subscription} from "rxjs";
import {JobsService} from "../../../../services/jobs.service";
import {AlertService} from "../../../../services/alert.service";
import {faCaretDown, faCaretUp} from "@fortawesome/free-solid-svg-icons";

@Component({
  selector: 'app-product-version',
  templateUrl: './product-version.component.html',
  styleUrls: ['./product-version.component.scss']
})
export class ProductVersionComponent implements OnInit, OnDestroy {

  @Input() version: ProductVersion;

  public showDetails = false;
  public jobspec$: Subscription;
  public jobspec: JobSpec;

  public faCaretDown = faCaretDown;
  public faCaretUp = faCaretUp;

  constructor(private jobService: JobsService, private alertService: AlertService) {
  }

  ngOnInit() {
  }

  hasDate(archiveId: any): string {
    if (archiveId.hasOwnProperty('key') &&
      archiveId.hasOwnProperty('value') &&
      archiveId.key === 'SdmId' &&
      archiveId.value.indexOf('.') > -1) {
      let parts = archiveId.value.split('.');
      let dateParts = parts.slice(Math.max(parts.length - 2, 1));
      // Modified Julian Day
      let MJD = parseFloat(dateParts.join('.'));
      // Julian day
      let jd = Math.floor(MJD) + 2400000.5;
      // Integer Julian day
      let jdi = Math.floor(jd);
      // Fractional part of day
      let jdf = jd - jdi + 0.5;

      let hour = jdf * 24.0;
      let l = jdi + 68569;
      let n = Math.floor(4 * l / 146097);

      l = Math.floor(l) - Math.floor((146097 * n + 3) / 4);
      let year = Math.floor(4000 * (l + 1) / 1461001);

      l = l - (Math.floor(1461 * year / 4)) + 31;
      let month = Math.floor(80 * l / 2447);

      let day = l - Math.floor(2447 * month / 80);

      l = Math.floor(month / 11);

      month = Math.floor(month + 2 - 12 * l);
      year = Math.floor(100 * (n - 49) + year + l);

      let rMonth = month.toString();
      if (month < 10) {
        rMonth = "0" + month;
      }

      let rDay = day.toString();
      if (day < 10) {
        rDay = "0" + day;
      }

      return `<span class="badge badge-light border ml-2 mr-1">Date</span>${rMonth}/${rDay}/${year}`;

    }
    return '';
  }

  toggleDetails(jobSpecId: string): void {
    if (this.showDetails) {
      this.showDetails = false;
    } else {
      this.getJobSpec(jobSpecId);
    }
  }

  getJobSpec(jobSpecId: string): void {
    this.showDetails = true;
    this.jobspec$ = this.jobService.getJobSpec(Number(jobSpecId)).subscribe((js: JobSpec) => {
      if (js) {
        this.jobspec = js;
      } else {
        this.alertService.error('Job Spec could not be retrieved');
      }
    });
  }

  ngOnDestroy(): void {
    if (this.jobspec$) {
      this.jobspec$.unsubscribe();
    }
  }
}
