import {Injectable} from '@angular/core';
import {Action} from "../model/action";
import {BehaviorSubject, Observable} from "rxjs";
import {StorageService} from "./storage.service";

@Injectable({
  providedIn: 'root'
})
export class ActionsService {

  private actionsTaken: Array<Action> = [];
  private _actionsTaken: BehaviorSubject<Array<Action>> = new BehaviorSubject<Array<Action>>(this.actionsTaken);
  public readonly actionsTaken$: Observable<Array<Action>> = this._actionsTaken.asObservable();

  constructor(private storageService: StorageService) {
    let savedActions = this.storageService.getLocal('actions_taken');
    if (savedActions) {
      savedActions = JSON.parse(savedActions);
      for (let sa of savedActions) {
        let tempAction = new Action(sa.type, sa.id);
        tempAction.timestamp = new Date(sa.timestamp);
        // we don't need day old stuff
        if (tempAction.timeSince < (1000 * 60 * 60 * 24)) {
          this.actionsTaken.push(tempAction);
        }
      }
    }

  }

  addAction(type: string, id: string | number) {
    this.actionsTaken.push(new Action(type, id));
    this.publish();
  }

  removeActionByTypeAndId(type: string, id: string | number) {
    this.actionsTaken = this.actionsTaken.filter((a: Action) => {
      return a.type !== type && a.id !== id;
    })
    this.publish();
  }

  private publish(): void {
    this.storageService.saveLocal('actions_taken', JSON.stringify(this.actionsTaken));
    this._actionsTaken.next(this.actionsTaken);
  }
}
